
From: Michael Krufky <mkrufky@m1k.net>

The #define CONFIG_DVB_* are actually CFLAGS set by Makefile.  CONFIG_*
namespace is reserved for Kconfig.  This renames them back to HAVE_*

Signed-off-by: Michael Krufky <mkrufky@m1k.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/media/video/cx88/Makefile         |    8 ++++----
 drivers/media/video/cx88/cx88-dvb.c       |   26 +++++++++++++-------------
 drivers/media/video/saa7134/Makefile      |    4 ++--
 drivers/media/video/saa7134/saa7134-dvb.c |   16 ++++++++--------
 4 files changed, 27 insertions(+), 27 deletions(-)

diff -puN drivers/media/video/cx88/cx88-dvb.c~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back drivers/media/video/cx88/cx88-dvb.c
--- devel/drivers/media/video/cx88/cx88-dvb.c~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back	2005-07-25 23:30:48.000000000 -0700
+++ devel-akpm/drivers/media/video/cx88/cx88-dvb.c	2005-07-25 23:31:13.000000000 -0700
@@ -1,5 +1,5 @@
 /*
- * $Id: cx88-dvb.c,v 1.50 2005/07/23 10:08:00 mkrufky Exp $
+ * $Id: cx88-dvb.c,v 1.52 2005/07/24 22:12:47 mkrufky Exp $
  *
  * device driver for Conexant 2388x based TV cards
  * MPEG Transport Stream (DVB) routines
@@ -35,17 +35,17 @@
 #include "cx88.h"
 #include "dvb-pll.h"
 
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 # include "mt352.h"
 # include "mt352_priv.h"
 #endif
-#ifdef CONFIG_DVB_CX22702
+#ifdef HAVE_CX22702
 # include "cx22702.h"
 #endif
-#ifdef CONFIG_DVB_OR51132
+#ifdef HAVE_OR51132
 # include "or51132.h"
 #endif
-#ifdef CONFIG_DVB_LGDT3302
+#ifdef HAVE_LGDT3302
 # include "lgdt3302.h"
 #endif
 
@@ -104,7 +104,7 @@ static struct videobuf_queue_ops dvb_qop
 
 /* ------------------------------------------------------------------ */
 
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 static int dvico_fusionhdtv_demod_init(struct dvb_frontend* fe)
 {
 	static u8 clock_config []  = { CLOCK_CTL,  0x38, 0x39 };
@@ -174,7 +174,7 @@ static struct mt352_config dntv_live_dvb
 };
 #endif
 
-#ifdef CONFIG_DVB_CX22702
+#ifdef HAVE_CX22702
 static struct cx22702_config connexant_refboard_config = {
 	.demod_address = 0x43,
 	.output_mode   = CX22702_SERIAL_OUTPUT,
@@ -190,7 +190,7 @@ static struct cx22702_config hauppauge_n
 };
 #endif
 
-#ifdef CONFIG_DVB_OR51132
+#ifdef HAVE_OR51132
 static int or51132_set_ts_param(struct dvb_frontend* fe,
 				int is_punctured)
 {
@@ -207,7 +207,7 @@ static struct or51132_config pchdtv_hd30
 };
 #endif
 
-#ifdef CONFIG_DVB_LGDT3302
+#ifdef HAVE_LGDT3302
 static int lgdt3302_pll_set(struct dvb_frontend* fe,
 			    struct dvb_frontend_parameters* params,
 			    u8* pllbuf)
@@ -258,7 +258,7 @@ static int dvb_register(struct cx8802_de
 
 	/* init frontend */
 	switch (dev->core->board) {
-#ifdef CONFIG_DVB_CX22702
+#ifdef HAVE_CX22702
 	case CX88_BOARD_HAUPPAUGE_DVB_T1:
 		dev->dvb.frontend = cx22702_attach(&hauppauge_novat_config,
 						   &dev->core->i2c_adap);
@@ -269,7 +269,7 @@ static int dvb_register(struct cx8802_de
 						   &dev->core->i2c_adap);
 		break;
 #endif
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 	case CX88_BOARD_DVICO_FUSIONHDTV_DVB_T1:
 		dev->core->pll_addr = 0x61;
 		dev->core->pll_desc = &dvb_pll_lg_z201;
@@ -291,13 +291,13 @@ static int dvb_register(struct cx8802_de
 						 &dev->core->i2c_adap);
 		break;
 #endif
-#ifdef CONFIG_DVB_OR51132
+#ifdef HAVE_OR51132
 	case CX88_BOARD_PCHDTV_HD3000:
 		dev->dvb.frontend = or51132_attach(&pchdtv_hd3000,
 						 &dev->core->i2c_adap);
 		break;
 #endif
-#ifdef CONFIG_DVB_LGDT3302
+#ifdef HAVE_LGDT3302
 	case CX88_BOARD_DVICO_FUSIONHDTV_3_GOLD_Q:
 		dev->ts_gen_cntrl = 0x08;
 		{
diff -puN drivers/media/video/cx88/Makefile~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back drivers/media/video/cx88/Makefile
--- devel/drivers/media/video/cx88/Makefile~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back	2005-07-25 23:30:48.000000000 -0700
+++ devel-akpm/drivers/media/video/cx88/Makefile	2005-07-25 23:30:48.000000000 -0700
@@ -10,14 +10,14 @@ EXTRA_CFLAGS += -I$(src)/..
 EXTRA_CFLAGS += -I$(srctree)/drivers/media/dvb/dvb-core
 EXTRA_CFLAGS += -I$(srctree)/drivers/media/dvb/frontends
 ifneq ($(CONFIG_DVB_CX22702),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_CX22702=1
+ EXTRA_CFLAGS += -DHAVE_CX22702=1
 endif
 ifneq ($(CONFIG_DVB_OR51132),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_OR51132=1
+ EXTRA_CFLAGS += -DHAVE_OR51132=1
 endif
 ifneq ($(CONFIG_DVB_LGDT3302),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_LGDT3302=1
+ EXTRA_CFLAGS += -DHAVE_LGDT3302=1
 endif
 ifneq ($(CONFIG_DVB_MT352),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_MT352=1
+ EXTRA_CFLAGS += -DHAVE_MT352=1
 endif
diff -puN drivers/media/video/saa7134/Makefile~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back drivers/media/video/saa7134/Makefile
--- devel/drivers/media/video/saa7134/Makefile~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back	2005-07-25 23:30:48.000000000 -0700
+++ devel-akpm/drivers/media/video/saa7134/Makefile	2005-07-25 23:30:48.000000000 -0700
@@ -10,8 +10,8 @@ EXTRA_CFLAGS += -I$(src)/..
 EXTRA_CFLAGS += -I$(srctree)/drivers/media/dvb/dvb-core
 EXTRA_CFLAGS += -I$(srctree)/drivers/media/dvb/frontends
 ifneq ($(CONFIG_DVB_MT352),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_MT352=1
+ EXTRA_CFLAGS += -DHAVE_MT352=1
 endif
 ifneq ($(CONFIG_DVB_TDA1004X),n)
- EXTRA_CFLAGS += -DCONFIG_DVB_TDA1004X=1
+ EXTRA_CFLAGS += -DHAVE_TDA1004X=1
 endif
diff -puN drivers/media/video/saa7134/saa7134-dvb.c~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back drivers/media/video/saa7134/saa7134-dvb.c
--- devel/drivers/media/video/saa7134/saa7134-dvb.c~v4l-hybrid-dvb-rename-cflags-from-config_dvb_xxxx-back	2005-07-25 23:30:48.000000000 -0700
+++ devel-akpm/drivers/media/video/saa7134/saa7134-dvb.c	2005-07-25 23:30:48.000000000 -0700
@@ -1,5 +1,5 @@
 /*
- * $Id: saa7134-dvb.c,v 1.22 2005/07/23 10:08:00 mkrufky Exp $
+ * $Id: saa7134-dvb.c,v 1.23 2005/07/24 22:12:47 mkrufky Exp $
  *
  * (c) 2004 Gerd Knorr <kraxel@bytesex.org> [SuSE Labs]
  *
@@ -35,11 +35,11 @@
 #include "saa7134-reg.h"
 #include "saa7134.h"
 
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 # include "mt352.h"
 # include "mt352_priv.h" /* FIXME */
 #endif
-#ifdef CONFIG_DVB_TDA1004X
+#ifdef HAVE_TDA1004X
 # include "tda1004x.h"
 #endif
 
@@ -53,7 +53,7 @@ MODULE_PARM_DESC(antenna_pwr,"enable ant
 
 /* ------------------------------------------------------------------ */
 
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 static int pinnacle_antenna_pwr(struct saa7134_dev *dev, int on)
 {
 	u32 ok;
@@ -152,7 +152,7 @@ static struct mt352_config pinnacle_300i
 
 /* ------------------------------------------------------------------ */
 
-#ifdef CONFIG_DVB_TDA1004X
+#ifdef HAVE_TDA1004X
 static int philips_tu1216_pll_init(struct dvb_frontend *fe)
 {
 	struct saa7134_dev *dev = fe->dvb->priv;
@@ -384,7 +384,7 @@ static int philips_fmd1216_pll_set(struc
 	return 0;
 }
 
-#ifdef CONFIG_DVB_TDA1004X
+#ifdef HAVE_TDA1004X
 static struct tda1004x_config medion_cardbus = {
 	.demod_address = 0x08,
 	.invert        = 1,
@@ -547,14 +547,14 @@ static int dvb_init(struct saa7134_dev *
 			    dev);
 
 	switch (dev->board) {
-#ifdef CONFIG_DVB_MT352
+#ifdef HAVE_MT352
 	case SAA7134_BOARD_PINNACLE_300I_DVBT_PAL:
 		printk("%s: pinnacle 300i dvb setup\n",dev->name);
 		dev->dvb.frontend = mt352_attach(&pinnacle_300i,
 						 &dev->i2c_adap);
 		break;
 #endif
-#ifdef CONFIG_DVB_TDA1004X
+#ifdef HAVE_TDA1004X
 	case SAA7134_BOARD_MD7134:
 		dev->dvb.frontend = tda10046_attach(&medion_cardbus,
 						    &dev->i2c_adap);
_
